summaryrefslogtreecommitdiffstats
path: root/qtinterface/interface_tqt3/tqlistiterator.h
diff options
context:
space:
mode:
authorMichele Calgaro <[email protected]>2018-10-17 23:25:45 +0900
committerMichele Calgaro <[email protected]>2018-10-17 23:25:45 +0900
commitb2cb8fdee255ddabee15e102a80ee720378d901d (patch)
treebbcfacd9f0d9ccbc8e126e43dd88692f2fd799ae /qtinterface/interface_tqt3/tqlistiterator.h
parent19da58656a063c39e48f251be084182cf2e68a8e (diff)
downloadtqtinterface-b2cb8fdee255ddabee15e102a80ee720378d901d.tar.gz
tqtinterface-b2cb8fdee255ddabee15e102a80ee720378d901d.zip
Removed obsolete Qt2's TQList/TQListIterator classes and replaced
with TQt3's TQPtrList/TQPtrListIterator ones. Signed-off-by: Michele Calgaro <[email protected]>
Diffstat (limited to 'qtinterface/interface_tqt3/tqlistiterator.h')
-rw-r--r--qtinterface/interface_tqt3/tqlistiterator.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/qtinterface/interface_tqt3/tqlistiterator.h b/qtinterface/interface_tqt3/tqlistiterator.h
index c4a0e60..fbe7c9d 100644
--- a/qtinterface/interface_tqt3/tqlistiterator.h
+++ b/qtinterface/interface_tqt3/tqlistiterator.h
@@ -26,7 +26,7 @@ Boston, MA 02110-1301, USA.
#ifdef USE_QT4
-// Implement the TQListIterator class
+// Implement the TQPtrListIterator class
// For Qt4, this is a combination of the QList::iterator and QMutableListIterator classes,
// with the constructor from QMutableListIterator used primarily
@@ -34,13 +34,13 @@ Boston, MA 02110-1301, USA.
#include <Qt/ntqlist.h>
template <typename T>
-//class TQListIterator : public QList<T>::iterator
-//class TQListIterator : public QMutableListIterator
-class TQListIterator
+//class TQPtrListIterator : public QList<T>::iterator
+//class TQPtrListIterator : public QMutableListIterator
+class TQPtrListIterator
{
public:
- inline TQListIterator(const QList<T> &t) {index = 0; list = &t;}
- inline ~TQListIterator() {}
+ inline TQPtrListIterator(const QList<T> &t) {index = 0; list = &t;}
+ inline ~TQPtrListIterator() {}
inline T current() {
if ((index >= 0) && (index < list->size())) {